# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-06 19:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ovp_uploads', '0003_uploadedimage_uuid'),
        ('ovp_users', '0009_user_phone'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='avatar',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='avatar_user', to='ovp_uploads.UploadedImage'),
        ),
    ]
